@@ -5,7 +5,6 @@
  *                            | (__| |_| |  _ <| |___
  *                             \___|\___/|_| \_\_____|
  *
- * $Id: lib549.c,v 1.2 2008-05-22 21:49:53 danf Exp $
  *
  * argv1 = URL
  * argv2 = proxy
@@ -14,6 +13,8 @@
 
 #include "test.h"
 
+#include "memdebug.h"
+
 int test(char *URL)
 {
   CURLcode res;
@@ -30,16 +31,19 @@ int test(char *URL)
     return TEST_ERR_MAJOR_BAD;
   }
 
-  curl_easy_setopt(curl, CURLOPT_PROXY, libtest_arg2);
-  curl_easy_setopt(curl, CURLOPT_URL, URL);
-  curl_easy_setopt(curl, CURLOPT_PROXY_TRANSFER_MODE, 1L);
-  curl_easy_setopt(curl, CURLOPT_VERBOSE, 1L);
-  if(libtest_arg3)
+  test_setopt(curl, CURLOPT_PROXY, libtest_arg2);
+  test_setopt(curl, CURLOPT_URL, URL);
+  test_setopt(curl, CURLOPT_PROXY_TRANSFER_MODE, 1L);
+  test_setopt(curl, CURLOPT_VERBOSE, 1L);
+  if(libtest_arg3) {
     /* enable ascii/text mode */
-    curl_easy_setopt(curl, CURLOPT_TRANSFERTEXT, 1L);
+    test_setopt(curl, CURLOPT_TRANSFERTEXT, 1L);
+  }
 
   res = curl_easy_perform(curl);
 
+test_cleanup:
+
   curl_easy_cleanup(curl);
   curl_global_cleanup();
 
